@@ -21,7 +21,7 @@ class TestMediawiki(BaseMediawikiTest):
         """
         BaseMediawikiTest.setUp(self, debug=debug, profile=profile)
         for wikiId in ["wiki","royals","cr"]:
-            self.getWikiUser(wikiId, save=True)
+            self.getSMWAccess(wikiId, save=True)
             
     def check_contexts(self,wikiId:str,ignoreExceptions:bool=True):
         """
@@ -33,7 +33,7 @@ class TestMediawiki(BaseMediawikiTest):
         """
         mw_contexts={}
         try:
-            smwAccess=SMWAccess(wikiId,debug=self.debug)
+            smwAccess=self.smwAccessMap[wikiId]
             mw_contexts=smwAccess.getMwContexts()
             for name,mw_context in mw_contexts.items():
                 print(f"{name}: {mw_context.sidif_url()}")
@@ -99,6 +99,18 @@ class TestMediawiki(BaseMediawikiTest):
         self.assertEqual(10,len(props))
         self.assertTrue("pluralName",props[1].name)  
         
+    def testAskQuery4Topic(self):
+        """
+        test creating the askquery for a topic
+        """
+        debug=self.debug
+        debug=True
+        context=self.getContext(debug=debug)
+        topic=context.topics["Property"]
+        ask_query=topic.askQuery()
+        if debug:
+            print(ask_query)
+        
     def test_topicLinks(self):
         """
         test topic links
@@ -148,7 +160,7 @@ class TestMediawiki(BaseMediawikiTest):
             self.assertIsNone(errMsg)
             self.assertTrue("OsProject" in context.topics)
             pass
-        
+                
     def test_metamodel_from_wikis(self):
         """
         test reading meta models from wikis
